@@ -1,7 +1,7 @@
 package Module::DataPack;
 
 our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,11 +41,6 @@ _
     args_rels => {
         req_one => ['module_names', 'module_srcs'],
         'dep_any&' => [
-            [stripper_maintain_linum => ['stripper']],
-            [stripper_ws             => ['stripper']],
-            [stripper_comment        => ['stripper']],
-            [stripper_pod            => ['stripper']],
-            [stripper_log            => ['stripper']],
         ],
     },
     args => {
@@ -93,73 +88,6 @@ _
             tags => ['category:output'],
         },
 
-        stripper => {
-            summary => 'Whether to strip included modules using Perl::Stripper',
-            'summary.alt.bool.yes' => 'Strip included modules using Perl::Stripper',
-            schema => ['bool' => default=>0],
-            tags => ['category:stripping'],
-        },
-        stripper_maintain_linum => {
-            summary => "Set maintain_linum=1 in Perl::Stripper",
-            schema => ['bool'],
-            default => 0,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_ws => {
-            summary => "Set strip_ws=1 (strip whitespace) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_ws=0 (don't strip whitespace) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_comment => {
-            summary => "Set strip_comment=1 (strip comments) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_comment=0 (don't strip comments) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-            tags => ['category:stripping'],
-        },
-        stripper_pod => {
-            summary => "Set strip_pod=1 (strip POD) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_pod=0 (don't strip POD) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_log => {
-            summary => "Set strip_log=1 (strip log statements) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_log=0 (don't strip log statements) in Perl::Stripper",
-            schema => ['bool'],
-            default => 0,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        # XXX strip_log_levels
-
     },
 };
 sub datapack_modules {
@@ -299,6 +227,8 @@ _
     }
 }
 
+require PERLANCAR::AppUtil::PerlStripper; PERLANCAR::AppUtil::PerlStripper::_add_stripper_args_to_meta($SPEC{datapack_modules});
+
 1;
 # ABSTRACT: Like Module::FatPack, but uses datapacking instead of fatpack
 
@@ -314,7 +244,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.02 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-06-17.
+This document describes version 0.03 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-06-17.
 
 =head1 SEE ALSO
 
